@@ -446,6 +446,15 @@ sub _generate_build {
             'clean: %%MAKE%% clean',
         );
     }
+    elsif ( -f catfile( $source_dir, 'configure.cmake' ) ) {
+        $self->log->info( 'detected cmake build system' );
+        @commands = (
+            'configure: cmake . -DCMAKE_INSTALL_PREFIX=%%INSTALL_BASE%%',
+            'make: %%MAKE%%',
+            'install: %%MAKE%% install',
+            'clean: %%MAKE%% clean',
+        );
+    }
     else {
         my ($name) = $source_dir =~ /([-\w.]+)$/;
         $self->log->warn(<<EOF);
@@ -459,6 +468,7 @@ EOF
             '# Edit this file to specify commands for building this dist.',
             '# See the perldoc for Shipwright::Manual::CustomizeBuild for more',
             '# info.',
+            'configure: ',
             'make: ',
             'test: ',
             'install: ',
