@@ -75,27 +75,20 @@ sub new {
 
 sub type {
     my $source = shift;
+    return unless $$source;
 
     _translate_source($source);
 
-    # prefix that can't be omitted
-    if ( $$source =~ /^file:.*\.(?:tar\.(?:gz|bz2)|tgz|tbz|zip)$/ ) {
-        $$source =~ s/^file://i;
-        return 'Compressed';
+    if ( $$source =~ /\.(?:tar\.(?:gz|bz2)|tgz|tbz|zip)$/ ) {
+        if ( $$source =~ s/^file://i || -f $$source ) {
+            return 'Compressed';
+        }
     }
 
-    return 'Directory'  if $$source =~ s/^dir(?:ectory)?://i;
+    return 'Directory' if $$source =~ s/^dir(?:ectory)?://i;
+
     return 'Shipyard' if $$source =~ s/^(?:shipyard|shipwright)://i;
 
-    if ( $$source =~ s/^cpan://i ) {
-
-        # if it's not a distribution name like
-        # 'S/SU/SUNNAVY/IP-QQWry-v0.0.15.tar.gz', convert '-' to '::'.
-        $$source =~ s/-/::/g
-          unless $$source =~ /\.(?:tar\.(?:gz|bz2)|tgz|tbz)$/;
-        return 'CPAN';
-    }
-
     # prefix that can be omitted
     for my $type (qw/svn http ftp git/) {
         if ( $$source =~ /^$type:/i ) {
@@ -109,6 +102,21 @@ sub type {
         return 'SVK';
     }
 
+    return 'Directory' if -d $$source;
+
+    # default is cpan module or distribution
+    $$source =~ s!^cpan:!!i;
+
+    return if $$source =~ /:/ && $$source !~ /::/;
+
+
+    # if it's not a distribution name like
+    # 'S/SU/SUNNAVY/IP-QQWry-v0.0.15.tar.gz', convert '-' to '::'.
+    $$source =~ s/-/::/g
+      unless $$source =~ /\.(?:tar\.(?:gz|bz2)|tgz|tbz)$/;
+
+    return 'CPAN';
+
 }
 
 sub _translate_source {
@@ -130,7 +138,7 @@ sunnavy  C<< <sunnavy@bestpractical.com> >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Shipwright is Copyright 2007-2010 Best Practical Solutions, LLC.
+Shipwright is Copyright 2007-2011 Best Practical Solutions, LLC.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
